==> qmmp_0.7.4.orig.tar.gz: qmmp-0.7.4/src/plugins/Visual/projectm/translations/projectm_plugin_gl_ES.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="gl_ES">
<context>
    <name>ProjectMPlugin</name>
    <message>
        <location filename="../projectmplugin.cpp" line="39"/>
        <source>ProjectM</source>
        <translation>ProjectM</translation>
    </message>
</context>
<context>
    <name>ProjectMWidget</name>
    <message>
        <location filename="../projectmwidget.cpp" line="134"/>
        <source>&amp;Help</source>
        <translation>&amp;Axuda</translation>
    </message>
    <message>
        <location filename="../projectmwidget.cpp" line="134"/>
        <source>F1</source>
        <translation>F1</translation>
    </message>
    <message>
        <location filename="../projectmwidget.cpp" line="135"/>
        <source>&amp;Show Song Title</source>
        <translation>&amp;Amosar título de canción</translation>
    </message>
    <message>
        <location filename="../projectmwidget.cpp" line="135"/>
        <source>F2</source>
        <translation>F2</translation>
    </message>
    <message>
        <location filename="../projectmwidget.cpp" line="136"/>
        <source>&amp;Show Preset Name</source>
        <translation>&amp;Amosar nome de perfil</translation>
    </message>
    <message>
        <location filename="../projectmwidget.cpp" line="136"/>
        <source>F3</source>
        <translation>F3</translation>
    </message>
    <message>
        <location filename="../projectmwidget.cpp" line="138"/>
        <source>&amp;Next Preset</source>
        <translation>&amp;Perfil seguinte</translation>
    </message>
    <message>
        <location filename="../projectmwidget.cpp" line="138"/>
        <source>N</source>
        <translation>N</translation>
    </message>
    <message>
        <location filename="../projectmwidget.cpp" line="139"/>
        <source>&amp;Previous Preset</source>
        <translation>&amp;Perfil anterior</translation>
    </message>
    <message>
        <location filename="../projectmwidget.cpp" line="139"/>
        <source>P</source>
        <translation>P</translation>
    </message>
    <message>
        <location filename="../projectmwidget.cpp" line="140"/>
        <source>&amp;Random Preset</source>
        <translation>&amp;Perfil aleatorio</translation>
    </message>
    <message>
        <location filename="../projectmwidget.cpp" line="140"/>
        <source>R</source>
        <translation>R</translation>
    </message>
    <message>
        <location filename="../projectmwidget.cpp" line="141"/>
        <source>&amp;Lock Preset</source>
        <translation>&amp;Bloquear perfil</translation>
    </message>
    <message>
        <location filename="../projectmwidget.cpp" line="141"/>
        <source>L</source>
        <translation>L</translation>
    </message>
    <message>
        <location filename="../projectmwidget.cpp" line="143"/>
        <source>&amp;Fullscreen</source>
        <translation>&amp;Pantalla completa</translation>
    </message>
    <message>
        <location filename="../projectmwidget.cpp" line="143"/>
        <source>F</source>
        <translation>F</translation>
    </message>
</context>
<context>
    <name>VisualProjectMFactory</name>
    <message>
        <location filename="../visualprojectmfactory.cpp" line="29"/>
        <source>ProjectM</source>
        <translation>ProjectM</translation>
    </message>
    <message>
        <location filename="../visualprojectmfactory.cpp" line="49"/>
        <source>About ProjectM Visual Plugin</source>
        <translation>Sobre o engadido visual ProjectM</translation>
    </message>
    <message>
        <location filename="../visualprojectmfactory.cpp" line="50"/>
        <source>Qmmp ProjectM Visual Plugin</source>
        <translation>Engadido ProjectM de Qmmp</translation>
    </message>
    <message>
        <location filename="../visualprojectmfactory.cpp" line="51"/>
        <source>This plugin adds projectM visualization</source>
        <translation>Este engadido provén visualización ProjectM</translation>
    </message>
    <message>
        <location filename="../visualprojectmfactory.cpp" line="52"/>
        <source>Written by: Ilya Kotov &lt;forkotov02@hotmail.ru&gt;</source>
        <translation>Escrito por: Ilya Kotov &lt;forkotov02@hotmail.ru&gt;</translation>
    </message>
    <message>
        <location filename="../visualprojectmfactory.cpp" line="53"/>
        <source>Based on llibrojectM-qt library</source>
        <translation>Baseado na libraría libprojectM-qt</translation>
    </message>
</context>
</TS>

==> qmmp_0.10.5.orig.tar.gz: qmmp-0.10.5/src/plugins/Visual/projectm/translations/projectm_plugin_gl_ES.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="gl_ES">
<context>
    <name>ProjectMPlugin</name>
    <message>
        <location filename="../projectmplugin.cpp" line="41"/>
        <source>ProjectM</source>
        <translation>ProjectM</translation>
    </message>
</context>
<context>
    <name>ProjectMWidget</name>
    <message>
        <location filename="../projectmwidget.cpp" line="164"/>
        <source>&amp;Help</source>
        <translation>&amp;Axuda</translation>
    </message>
    <message>
        <location filename="../projectmwidget.cpp" line="164"/>
        <source>F1</source>
        <translation>F1</translation>
    </message>
    <message>
        <location filename="../projectmwidget.cpp" line="165"/>
        <source>&amp;Show Song Title</source>
        <translation>&amp;Amosar título de canción</translation>
    </message>
    <message>
        <location filename="../projectmwidget.cpp" line="165"/>
        <source>F2</source>
        <translation>F2</translation>
    </message>
    <message>
        <location filename="../projectmwidget.cpp" line="166"/>
        <source>&amp;Show Preset Name</source>
        <translation>&amp;Amosar nome de perfil</translation>
    </message>
    <message>
        <location filename="../projectmwidget.cpp" line="166"/>
        <source>F3</source>
        <translation>F3</translation>
    </message>
    <message>
        <location filename="../projectmwidget.cpp" line="167"/>
        <source>&amp;Show Menu</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../projectmwidget.cpp" line="167"/>
        <source>M</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../projectmwidget.cpp" line="169"/>
        <source>&amp;Next Preset</source>
        <translation>&amp;Perfil seguinte</translation>
    </message>
    <message>
        <location filename="../projectmwidget.cpp" line="169"/>
        <source>N</source>
        <translation>N</translation>
    </message>
    <message>
        <location filename="../projectmwidget.cpp" line="170"/>
        <source>&amp;Previous Preset</source>
        <translation>&amp;Perfil anterior</translation>
    </message>
    <message>
        <location filename="../projectmwidget.cpp" line="170"/>
        <source>P</source>
        <translation>P</translation>
    </message>
    <message>
        <location filename="../projectmwidget.cpp" line="171"/>
        <source>&amp;Random Preset</source>
        <translation>&amp;Perfil aleatorio</translation>
    </message>
    <message>
        <location filename="../projectmwidget.cpp" line="171"/>
        <source>R</source>
        <translation>R</translation>
    </message>
    <message>
        <location filename="../projectmwidget.cpp" line="172"/>
        <source>&amp;Lock Preset</source>
        <translation>&amp;Bloquear perfil</translation>
    </message>
    <message>
        <location filename="../projectmwidget.cpp" line="172"/>
        <source>L</source>
        <translation>L</translation>
    </message>
    <message>
        <location filename="../projectmwidget.cpp" line="174"/>
        <source>&amp;Fullscreen</source>
        <translation>&amp;Pantalla completa</translation>
    </message>
    <message>
        <location filename="../projectmwidget.cpp" line="174"/>
        <source>F</source>
        <translation>F</translation>
    </message>
</context>
<context>
    <name>VisualProjectMFactory</name>
    <message>
        <location filename="../visualprojectmfactory.cpp" line="31"/>
        <source>ProjectM</source>
        <translation>ProjectM</translation>
    </message>
    <message>
        <location filename="../visualprojectmfactory.cpp" line="51"/>
        <source>About ProjectM Visual Plugin</source>
        <translation>Sobre o engadido visual ProjectM</translation>
    </message>
    <message>
        <location filename="../visualprojectmfactory.cpp" line="52"/>
        <source>Qmmp ProjectM Visual Plugin</source>
        <translation>Engadido ProjectM de Qmmp</translation>
    </message>
    <message>
        <location filename="../visualprojectmfactory.cpp" line="53"/>
        <source>This plugin adds projectM visualization</source>
        <translation>Este engadido provén visualización ProjectM</translation>
    </message>
    <message>
        <location filename="../visualprojectmfactory.cpp" line="54"/>
        <source>Written by: Ilya Kotov &lt;forkotov02@hotmail.ru&gt;</source>
        <translation>Escrito por: Ilya Kotov &lt;forkotov02@hotmail.ru&gt;</translation>
    </message>
    <message>
        <location filename="../visualprojectmfactory.cpp" line="55"/>
        <source>Based on libprojectM-qt library</source>
        <translation>Baseado na libraría libprojectM-qt</translation>
    </message>
</context>
</TS>
